@@ -39,11 +39,14 @@ class Mailer {
      */
     public function __construct() {
         global $conf;
+        /* @var Input $INPUT */
+        global $INPUT;
 
         $server = parse_url(DOKU_URL, PHP_URL_HOST);
+        if(strpos($server,'.') === false) $server = $server.'.localhost';
 
-        $this->partid   = md5(uniqid(rand(), true)).'@'.$server;
-        $this->boundary = '----------'.md5(uniqid(rand(), true));
+        $this->partid   = substr(md5(uniqid(rand(), true)),0, 8).'@'.$server;
+        $this->boundary = '__________'.md5(uniqid(rand(), true));
 
         $listid = join('.', array_reverse(explode('/', DOKU_BASE))).$server;
         $listid = strtolower(trim($listid, '.'));
@@ -51,12 +54,13 @@ class Mailer {
         $this->allowhtml = (bool)$conf['htmlmail'];
 
         // add some default headers for mailfiltering FS#2247
-        $this->setHeader('X-Mailer', 'DokuWiki '.getVersion());
-        $this->setHeader('X-DokuWiki-User', $_SERVER['REMOTE_USER']);
+        $this->setHeader('X-Mailer', 'DokuWiki');
+        $this->setHeader('X-DokuWiki-User', $INPUT->server->str('REMOTE_USER'));
         $this->setHeader('X-DokuWiki-Title', $conf['title']);
         $this->setHeader('X-DokuWiki-Server', $server);
         $this->setHeader('X-Auto-Response-Suppress', 'OOF');
         $this->setHeader('List-Id', $conf['title'].' <'.$listid.'>');
+        $this->setHeader('Date', date('r'), false);
     }
 
     /**
@@ -104,6 +108,9 @@ class Mailer {
 
     /**
      * Callback function to automatically embed images referenced in HTML templates
+     *
+     * @param array $matches
+     * @return string placeholder
      */
     protected function autoembed_cb($matches) {
         static $embeds = 0;
@@ -126,7 +133,7 @@ class Mailer {
      * If an empy value is passed, the header is removed
      *
      * @param string $header the header name (no trailing colon!)
-     * @param string $value  the value of the header
+     * @param string|string[] $value  the value of the header
      * @param bool   $clean  remove all non-ASCII chars and line feeds?
      */
     public function setHeader($header, $value, $clean = true) {
@@ -137,7 +144,13 @@ class Mailer {
         }
 
         // empty value deletes
-        $value = trim($value);
+        if(is_array($value)){
+            $value = array_map('trim', $value);
+            $value = array_filter($value);
+            if(!$value) $value = '';
+        }else{
+            $value = trim($value);
+        }
         if($value === '') {
             if(isset($this->headers[$header])) unset($this->headers[$header]);
         } else {
@@ -150,6 +163,8 @@ class Mailer {
      *
      * Whatever is set here is directly passed to PHP's mail() command as last
      * parameter. Depending on the PHP setup this might break mailing alltogether
+     *
+     * @param string $param
      */
     public function setParameters($param) {
         $this->sendparam = $param;
@@ -167,12 +182,15 @@ class Mailer {
      * @param string $text     plain text body
      * @param array  $textrep  replacements to apply on the text part
      * @param array  $htmlrep  replacements to apply on the HTML part, leave null to use $textrep
-     * @param array  $html     the HTML body, leave null to create it from $text
+     * @param string $html     the HTML body, leave null to create it from $text
      * @param bool   $wrap     wrap the HTML in the default header/Footer
      */
     public function setBody($text, $textrep = null, $htmlrep = null, $html = null, $wrap = true) {
         global $INFO;
         global $conf;
+        /* @var Input $INPUT */
+        global $INPUT;
+
         $htmlrep = (array)$htmlrep;
         $textrep = (array)$textrep;
 
@@ -192,7 +210,7 @@ class Mailer {
         // copy over all replacements missing for HTML (autolink URLs)
         foreach($textrep as $key => $value) {
             if(isset($htmlrep[$key])) continue;
-            if(preg_match('/^https?:\/\//i', $value)) {
+            if(media_isexternal($value)) {
                 $htmlrep[$key] = '<a href="'.hsc($value).'">'.hsc($value).'</a>';
             } else {
                 $htmlrep[$key] = hsc($value);
@@ -210,24 +228,24 @@ class Mailer {
         $cip  = gethostsbyaddrs($ip);
         $trep = array(
             'DATE'        => dformat(),
-            'BROWSER'     => $_SERVER['HTTP_USER_AGENT'],
+            'BROWSER'     => $INPUT->server->str('HTTP_USER_AGENT'),
             'IPADDRESS'   => $ip,
             'HOSTNAME'    => $cip,
             'TITLE'       => $conf['title'],
             'DOKUWIKIURL' => DOKU_URL,
-            'USER'        => $_SERVER['REMOTE_USER'],
+            'USER'        => $INPUT->server->str('REMOTE_USER'),
             'NAME'        => $INFO['userinfo']['name'],
             'MAIL'        => $INFO['userinfo']['mail'],
         );
         $trep = array_merge($trep, (array)$textrep);
         $hrep = array(
             'DATE'        => '<i>'.hsc(dformat()).'</i>',
-            'BROWSER'     => hsc($_SERVER['HTTP_USER_AGENT']),
+            'BROWSER'     => hsc($INPUT->server->str('HTTP_USER_AGENT')),
             'IPADDRESS'   => '<code>'.hsc($ip).'</code>',
             'HOSTNAME'    => '<code>'.hsc($cip).'</code>',
             'TITLE'       => hsc($conf['title']),
             'DOKUWIKIURL' => '<a href="'.DOKU_URL.'">'.DOKU_URL.'</a>',
-            'USER'        => hsc($_SERVER['REMOTE_USER']),
+            'USER'        => hsc($INPUT->server->str('REMOTE_USER')),
             'NAME'        => hsc($INFO['userinfo']['name']),
             'MAIL'        => '<a href="mailto:"'.hsc($INFO['userinfo']['mail']).'">'.
                 hsc($INFO['userinfo']['mail']).'</a>',
@@ -252,6 +270,8 @@ class Mailer {
      * Placeholders can be used to reference embedded attachments
      *
      * You probably want to use setBody() instead
+     *
+     * @param string $html
      */
     public function setHTML($html) {
         $this->html = $html;
@@ -261,6 +281,8 @@ class Mailer {
      * Set the plain text part of the mail
      *
      * You probably want to use setBody() instead
+     *
+     * @param string $text
      */
     public function setText($text) {
         $this->text = $text;
@@ -269,8 +291,8 @@ class Mailer {
     /**
      * Add the To: recipients
      *
-     * @see setAddress
-     * @param string  $address Multiple adresses separated by commas
+     * @see cleanAddress
+     * @param string|string[]  $address Multiple adresses separated by commas or as array
      */
     public function to($address) {
         $this->setHeader('To', $address, false);
@@ -279,8 +301,8 @@ class Mailer {
     /**
      * Add the Cc: recipients
      *
-     * @see setAddress
-     * @param string  $address Multiple adresses separated by commas
+     * @see cleanAddress
+     * @param string|string[]  $address Multiple adresses separated by commas or as array
      */
     public function cc($address) {
         $this->setHeader('Cc', $address, false);
@@ -289,8 +311,8 @@ class Mailer {
     /**
      * Add the Bcc: recipients
      *
-     * @see setAddress
-     * @param string  $address Multiple adresses separated by commas
+     * @see cleanAddress
+     * @param string|string[]  $address Multiple adresses separated by commas or as array
      */
     public function bcc($address) {
         $this->setHeader('Bcc', $address, false);
@@ -302,7 +324,7 @@ class Mailer {
      * This is set to $conf['mailfrom'] when not specified so you shouldn't need
      * to call this function
      *
-     * @see setAddress
+     * @see cleanAddress
      * @param string  $address from address
      */
     public function from($address) {
@@ -325,20 +347,22 @@ class Mailer {
      * for headers. Addresses may not contain Non-ASCII data!
      *
      * Example:
-     *   setAddress("föö <foo@bar.com>, me@somewhere.com","TBcc");
+     *   cc("föö <foo@bar.com>, me@somewhere.com","TBcc");
      *
-     * @param string  $address Multiple adresses separated by commas
-     * @return bool|string  the prepared header (can contain multiple lines)
+     * @param string|string[]  $addresses Multiple adresses separated by commas or as array
+     * @return false|string  the prepared header (can contain multiple lines)
      */
-    public function cleanAddress($address) {
+    public function cleanAddress($addresses) {
         // No named recipients for To: in Windows (see FS#652)
         $names = (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') ? false : true;
 
-        $address = preg_replace('/[\r\n\0]+/', ' ', $address); // remove attack vectors
-
         $headers = '';
-        $parts   = explode(',', $address);
-        foreach($parts as $part) {
+        if(!is_array($addresses)){
+            $addresses = explode(',', $addresses);
+        }
+
+        foreach($addresses as $part) {
+            $part = preg_replace('/[\r\n\0]+/', ' ', $part); // remove attack vectors
             $part = trim($part);
 
             // parse address
@@ -378,7 +402,7 @@ class Mailer {
                     $text = utf8_strip($text);
                 }
 
-                if(!utf8_isASCII($text)) {
+                if(strpos($text, ',') !== false || !utf8_isASCII($text)) {
                     $text = '=?UTF-8?B?'.base64_encode($text).'?=';
                 }
             } else {
@@ -392,6 +416,7 @@ class Mailer {
             $headers .= $text.' '.$addr;
         }
 
+        $headers = trim($headers);
         if(empty($headers)) return false;
 
         return $headers;
@@ -402,12 +427,16 @@ class Mailer {
      * Prepare the mime multiparts for all attachments
      *
      * Replaces placeholders in the HTML with the correct CIDs
+     *
+     * @return string mime multiparts
      */
     protected function prepareAttachments() {
         $mime = '';
         $part = 1;
         // embedded attachments
         foreach($this->attach as $media) {
+            $media['name'] = str_replace(':', '_', cleanID($media['name'], true));
+
             // create content id
             $cid = 'part'.$part.'.'.$this->partid;
 
@@ -417,13 +446,13 @@ class Mailer {
             }
 
             $mime .= '--'.$this->boundary.MAILHEADER_EOL;
-            $mime .= 'Content-Type: '.$media['mime'].';'.MAILHEADER_EOL;
-            $mime .= 'Content-Transfer-Encoding: base64'.MAILHEADER_EOL;
-            $mime .= "Content-ID: <$cid>".MAILHEADER_EOL;
+            $mime .= $this->wrappedHeaderLine('Content-Type', $media['mime'].'; id="'.$cid.'"');
+            $mime .= $this->wrappedHeaderLine('Content-Transfer-Encoding', 'base64');
+            $mime .= $this->wrappedHeaderLine('Content-ID',"<$cid>");
             if($media['embed']) {
-                $mime .= 'Content-Disposition: inline; filename="'.$media['name'].'"'.MAILHEADER_EOL;
+                $mime .= $this->wrappedHeaderLine('Content-Disposition', 'inline; filename='.$media['name']);
             } else {
-                $mime .= 'Content-Disposition: attachment; filename="'.$media['name'].'"'.MAILHEADER_EOL;
+                $mime .= $this->wrappedHeaderLine('Content-Disposition', 'attachment; filename='.$media['name']);
             }
             $mime .= MAILHEADER_EOL; //end of headers
             $mime .= chunk_split(base64_encode($media['data']), 74, MAILHEADER_EOL);
@@ -460,7 +489,7 @@ class Mailer {
         if(!$this->html && !count($this->attach)) { // we can send a simple single part message
             $this->headers['Content-Type']              = 'text/plain; charset=UTF-8';
             $this->headers['Content-Transfer-Encoding'] = 'base64';
-            $body .= chunk_split(base64_encode($this->text), 74, MAILHEADER_EOL);
+            $body .= chunk_split(base64_encode($this->text), 72, MAILHEADER_EOL);
         } else { // multi part it is
             $body .= "This is a multi-part message in MIME format.".MAILHEADER_EOL;
 
@@ -475,10 +504,11 @@ class Mailer {
                 $body .= 'Content-Type: text/plain; charset=UTF-8'.MAILHEADER_EOL;
                 $body .= 'Content-Transfer-Encoding: base64'.MAILHEADER_EOL;
                 $body .= MAILHEADER_EOL;
-                $body .= chunk_split(base64_encode($this->text), 74, MAILHEADER_EOL);
+                $body .= chunk_split(base64_encode($this->text), 72, MAILHEADER_EOL);
                 $body .= '--'.$this->boundary.'XX'.MAILHEADER_EOL;
                 $body .= 'Content-Type: multipart/related;'.MAILHEADER_EOL.
-                    '  boundary="'.$this->boundary.'"'.MAILHEADER_EOL;
+                    '  boundary="'.$this->boundary.'";'.MAILHEADER_EOL.
+                    '  type="text/html"'.MAILHEADER_EOL;
                 $body .= MAILHEADER_EOL;
             }
 
@@ -486,7 +516,7 @@ class Mailer {
             $body .= 'Content-Type: text/html; charset=UTF-8'.MAILHEADER_EOL;
             $body .= 'Content-Transfer-Encoding: base64'.MAILHEADER_EOL;
             $body .= MAILHEADER_EOL;
-            $body .= chunk_split(base64_encode($this->html), 74, MAILHEADER_EOL);
+            $body .= chunk_split(base64_encode($this->html), 72, MAILHEADER_EOL);
             $body .= MAILHEADER_EOL;
             $body .= $attachments;
             $body .= '--'.$this->boundary.'--'.MAILHEADER_EOL;
@@ -508,7 +538,7 @@ class Mailer {
 
         // clean up addresses
         if(empty($this->headers['From'])) $this->from($conf['mailfrom']);
-        $addrs = array('To', 'From', 'Cc', 'Bcc');
+        $addrs = array('To', 'From', 'Cc', 'Bcc', 'Reply-To', 'Sender');
         foreach($addrs as $addr) {
             if(isset($this->headers[$addr])) {
                 $this->headers[$addr] = $this->cleanAddress($this->headers[$addr]);
@@ -541,10 +571,17 @@ class Mailer {
             }
         }
 
-        // wrap headers
-        foreach($this->headers as $key => $val) {
-            $this->headers[$key] = wordwrap($val, 78, MAILHEADER_EOL.'  ');
-        }
+    }
+
+    /**
+     * Returns a complete, EOL terminated header line, wraps it if necessary
+     *
+     * @param string $key
+     * @param string $val
+     * @return string line
+     */
+    protected function wrappedHeaderLine($key, $val){
+        return wordwrap("$key: $val", 78, MAILHEADER_EOL.'  ').MAILHEADER_EOL;
     }
 
     /**
@@ -555,7 +592,8 @@ class Mailer {
     protected function prepareHeaders() {
         $headers = '';
         foreach($this->headers as $key => $val) {
-            $headers .= "$key: $val".MAILHEADER_EOL;
+            if ($val === '' || is_null($val)) continue;
+            $headers .= $this->wrappedHeaderLine($key, $val);
         }
         return $headers;
     }
@@ -618,16 +656,16 @@ class Mailer {
             ) return false;
 
             // The To: header is special
-            if(isset($this->headers['To'])) {
-                $to = $this->headers['To'];
+            if(array_key_exists('To', $this->headers)) {
+                $to = (string)$this->headers['To'];
                 unset($this->headers['To']);
             } else {
                 $to = '';
             }
 
             // so is the subject
-            if(isset($this->headers['Subject'])) {
-                $subject = $this->headers['Subject'];
+            if(array_key_exists('Subject', $this->headers)) {
+                $subject = (string)$this->headers['Subject'];
                 unset($this->headers['Subject']);
             } else {
                 $subject = '';
