@@ -37,7 +37,6 @@ $lang['btn_update']            = 'Actualizar';
 $lang['btn_delete']            = 'Borrar';
 $lang['btn_back']              = 'Atrás';
 $lang['btn_backlink']          = 'Ligazóns con isto';
-$lang['btn_backtomedia']       = 'Volver á Selección de Arquivos-Media';
 $lang['btn_subscribe']         = 'Avísame dos trocos na páxina';
 $lang['btn_profile']           = 'Actualizar Perfil';
 $lang['btn_reset']             = 'Reiniciar';
@@ -141,7 +140,6 @@ $lang['js']['media_overwrt']   = 'Sobreescribir os arquivos existentes';
 $lang['rssfailed']             = 'Houbo un erro ao tentar obter esta corrente RSS: ';
 $lang['nothingfound']          = 'Non se atopou nada.';
 $lang['mediaselect']           = 'Arquivos-Media';
-$lang['fileupload']            = 'Subida de Arquivos-Media';
 $lang['uploadsucc']            = 'Subida correcta';
 $lang['uploadfail']            = 'Erra na subida. Pode que sexa un problema de permisos?';
 $lang['uploadwrong']           = 'Subida denegada. Esta extensión de arquivo non está permitida!';
@@ -227,7 +225,6 @@ $lang['qb_sig']                = 'Inserir Sinatura';
 $lang['qb_smileys']            = 'Risoños';
 $lang['qb_chars']              = 'Caracteres Especiais';
 $lang['upperns']               = 'choutar ao nome de espazo pai';
-$lang['admin_register']        = 'Engadir novo usuario';
 $lang['metaedit']              = 'Editar Metadatos';
 $lang['metasaveerr']           = 'Non se puideron escribir os metadatos';
 $lang['metasaveok']            = 'Metadatos gardados';
@@ -260,7 +257,6 @@ $lang['subscr_m_subscribe']    = 'Subscribir';
 $lang['subscr_m_receive']      = 'Recibir';
 $lang['subscr_style_every']    = 'correo-e en cada troco';
 $lang['authtempfail']          = 'A autenticación de usuario non está dispoñible de xeito temporal. De persistir esta situación, por favor, informa ao Administrador do teu Wiki.';
-$lang['authpwdexpire']         = 'A túa contrasinal expirará en %d días, deberías cambiala pronto.';
 $lang['i_chooselang']          = 'Escolle o teu idioma';
 $lang['i_installer']           = 'Instalador do DokuWiki';
 $lang['i_wikiname']            = 'Nome do Wiki';
@@ -278,9 +274,9 @@ $lang['i_writeerr']            = 'Non se puido crear <code>%s</code>. Terás de
 $lang['i_badhash']             = 'dokuwiki.php irrecoñecíbel ou modificado (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - ilegal ou valor baleiro';
 $lang['i_success']             = 'A configuración rematou correctamente. Agora podes eliminar o arquivo install.php. Continúa deica o
-                        <a href="doku.php">teu novo DokuWiki</a>.';
+                        <a href="doku.php?id=wiki:welcome">teu novo DokuWiki</a>.';
 $lang['i_failure']             = 'Houbo algúns erros ao tentar escribir os arquivos de configuración. Pode que precises solucionalos de xeito manual antes
-                         de poderes empregar <a href="doku.php">o teu novo DokuWiki</a>.';
+                         de poderes empregar <a href="doku.php?id=wiki:welcome">o teu novo DokuWiki</a>.';
 $lang['i_policy']              = 'Regras iniciais da ACL';
 $lang['i_pol0']                = 'Wiki Aberto (lectura, escritura, subida de arquivos para todas as persoas)';
 $lang['i_pol1']                = 'Wiki Público (lectura para todas as persoas, escritura e subida de arquivos para usuarios rexistrados)';
