@@ -37,7 +37,6 @@ $lang['btn_update']            = 'Ажурирај';
 $lang['btn_delete']            = 'Избриши';
 $lang['btn_back']              = 'Натраг';
 $lang['btn_backlink']          = 'Повратне везе';
-$lang['btn_backtomedia']       = 'Врати се на избор медијске датотеке';
 $lang['btn_subscribe']         = 'Пријави се на измене';
 $lang['btn_profile']           = 'Ажурирај профил';
 $lang['btn_reset']             = 'Поништи';
@@ -46,7 +45,7 @@ $lang['btn_recover']           = 'Опорави нацрт';
 $lang['btn_draftdel']          = 'Обриши нацрт';
 $lang['btn_revert']            = 'Врати на пређашњу верзију';
 $lang['btn_register']          = 'Региструј се';
-$lang['loggedinas']            = 'Пријављен као';
+$lang['loggedinas']            = 'Пријављен као:';
 $lang['user']                  = 'Корисничко име';
 $lang['pass']                  = 'Лозинка';
 $lang['newpass']               = 'Нова лозинка';
@@ -60,6 +59,7 @@ $lang['badlogin']              = 'Извините, није добро кори
 $lang['minoredit']             = 'Мала измена';
 $lang['draftdate']             = 'Нацрт је аутоматски сачуван';
 $lang['nosecedit']             = 'Страна је у међувремену промењена, поглавље је застарело и поново се учитава цела страна.';
+$lang['searchcreatepage']      = "Ако нисте нашли то што сте тражили, можете да направите нову страницу названу по Вашем упиту користећи дугме ''Измени ову страницу''.";
 $lang['regmissing']            = 'Извините, морате да попуните сва поља.';
 $lang['reguexists']            = 'Извините, корисник са истим именом већ постоји.';
 $lang['regsuccess']            = 'Корисник је направљен и лозинка је послата путем е-поште.';
@@ -84,11 +84,11 @@ $lang['license']               = 'Осим где је другачије наз
 $lang['licenseok']             = 'Напомена: Изменом ове стране слажете се да ће ваше измене бити под следећом лиценцом:';
 $lang['searchmedia']           = 'Претражи по имену фајла';
 $lang['searchmedia_in']        = 'Претражи у %s';
-$lang['txt_upload']            = 'Изаберите датотеку за слање';
-$lang['txt_filename']          = 'Унесите вики-име (опционо)';
+$lang['txt_upload']            = 'Изаберите датотеку за слање:';
+$lang['txt_filename']          = 'Унесите вики-име (опционо):';
 $lang['txt_overwrt']           = 'Препишите тренутни фајл';
-$lang['lockedby']              = 'Тренутно закључано од стране';
-$lang['lockexpire']            = 'Закључавање истиче';
+$lang['lockedby']              = 'Тренутно закључано од стране:';
+$lang['lockexpire']            = 'Закључавање истиче:';
 $lang['js']['willexpire']            = 'Ваше закључавање за измену ове странице ће да истекне за један минут.\nДа би сте избегли конфликте, искористите дугме за преглед како би сте ресетовали тајмер закључавања.';
 $lang['js']['notsavedyet']     = 'Несачуване измене ће бити изгубљене.
 Да ли стварно желите да наставите?';
@@ -124,7 +124,6 @@ $lang['js']['del_confirm']     = 'Обриши овај унос?';
 $lang['rssfailed']             = 'Дошло је до грешке приликом преузимања овог довода: ';
 $lang['nothingfound']          = 'Ништа није нађено.';
 $lang['mediaselect']           = 'Избор медијске датотеке';
-$lang['fileupload']            = 'Слање медијске датотеке';
 $lang['uploadsucc']            = 'Успешно слање';
 $lang['uploadfail']            = 'Неуспешно слање. Можда немате дозволу?';
 $lang['uploadwrong']           = 'Слање је забрањено. Овај наставак датотеке је забрањен!';
@@ -156,9 +155,9 @@ $lang['diff']                  = 'прикажи разлике до трену
 $lang['diff2']                 = 'Прикажи разлике између одабраних ревизија';
 $lang['difflink']              = 'Постави везу ка овом компаративном приказу';
 $lang['line']                  = 'Линија';
-$lang['breadcrumb']            = 'Траг';
-$lang['youarehere']            = 'Сада сте овде';
-$lang['lastmod']               = 'Последњи пут мењано';
+$lang['breadcrumb']            = 'Траг:';
+$lang['youarehere']            = 'Сада сте овде:';
+$lang['lastmod']               = 'Последњи пут мењано:';
 $lang['by']                    = 'од';
 $lang['deleted']               = 'избрисано';
 $lang['created']               = 'направљено';
@@ -197,21 +196,20 @@ $lang['qb_sig']                = 'Убаци потпис';
 $lang['qb_smileys']            = 'Смешко';
 $lang['qb_chars']              = 'Посебни карактери';
 $lang['upperns']               = 'Скочи на виши именски простор';
-$lang['admin_register']        = 'Додај новог корисника';
 $lang['metaedit']              = 'Измени мета-податке';
 $lang['metasaveerr']           = 'Записивање мета-података није било успешно';
 $lang['metasaveok']            = 'Мета-подаци су сачувани';
-$lang['img_backto']            = 'Натраг на';
-$lang['img_title']             = 'Наслов';
-$lang['img_caption']           = 'Назив';
-$lang['img_date']              = 'Датум';
-$lang['img_fname']             = 'Име фајла';
-$lang['img_fsize']             = 'Величина';
-$lang['img_artist']            = 'Фотограф';
-$lang['img_copyr']             = 'Права копирања';
-$lang['img_format']            = 'Формат';
-$lang['img_camera']            = 'Камера';
-$lang['img_keywords']          = 'Кључне речи';
+$lang['btn_img_backto']            = 'Натраг на %s';
+$lang['img_title']             = 'Наслов:';
+$lang['img_caption']           = 'Назив:';
+$lang['img_date']              = 'Датум:';
+$lang['img_fname']             = 'Име фајла:';
+$lang['img_fsize']             = 'Величина:';
+$lang['img_artist']            = 'Фотограф:';
+$lang['img_copyr']             = 'Права копирања:';
+$lang['img_format']            = 'Формат:';
+$lang['img_camera']            = 'Камера:';
+$lang['img_keywords']          = 'Кључне речи:';
 $lang['subscr_subscribe_success'] = '%s је додат на списак претплатника %s';
 $lang['subscr_subscribe_error'] = 'Грешка приликом додавања %s на списак претплатника %s';
 $lang['subscr_subscribe_noaddress'] = 'Не постоји адреса повезана са вашим подацима, стога вас не можемо додати на списак претплатника.';
@@ -228,7 +226,6 @@ $lang['subscr_m_receive']      = 'Прими';
 $lang['subscr_style_every']    = 'имејл о свакој промени';
 $lang['subscr_style_digest']   = 'скраћени имејл о променама за сваку страницу (сваких %.2f дана)';
 $lang['subscr_style_list']     = 'Списак страница промењених након последњег имејла (сваких %.2f дана)';
-$lang['authmodfailed']         = 'Лоше подешена провера корисника. Молим Вас да обавестите администратора викија.';
 $lang['authtempfail']          = 'Провера корисника је тренутно недоступна. Ако се ситуација настави, молимо Вас да обавестите администратора викија.';
 $lang['i_chooselang']          = 'Одаберите језик';
 $lang['i_installer']           = 'Докувики инсталација';
