@@ -30,8 +30,6 @@ $lang['_links']                = 'Ajusts de vínculs';
 $lang['_media']                = 'Ajusts de mijos';
 $lang['_advanced']             = 'Ajusts alvançats';
 $lang['_network']              = 'Ajusts de ret';
-$lang['_plugin_sufix']         = 'Ajusts de plúgins';
-$lang['_template_sufix']       = '(ajusts de la plantilla)';
 $lang['_msg_setting_undefined'] = 'Ajust sense informació.';
 $lang['_msg_setting_no_class'] = 'Ajust sense classe.';
 $lang['_msg_setting_no_default'] = 'Sense valor predeterminat.';
@@ -62,7 +60,6 @@ $lang['camelcase']             = 'Utilisar CamelCase per als vínculs';
 $lang['deaccent']              = 'Depurar els noms de pàgines';
 $lang['useheading']            = 'Utilisar el primer titular per al nom de pàgina';
 $lang['refcheck']              = 'Comprovar referències a mijos';
-$lang['refshow']               = 'Número de referències a mijos a mostrar';
 $lang['allowdebug']            = 'Permetre depurar (<b>¡desactivar quan no es necessite!</b>)';
 $lang['usewordblock']          = 'Bloquejar spam basant-se en una llista de paraules';
 $lang['indexdelay']            = 'Retart abans d\'indexar (seg.)';
