@@ -23,7 +23,7 @@ function createToolButton(icon,label,key,id,classname){
         $btn.addClass(classname);
     }
 
-    $btn.attr('title', label);
+    $btn.attr('title', label).attr('aria-controls', 'wiki__text');
     if(key){
         $btn.attr('title', label + ' ['+key.toUpperCase()+']')
             .attr('accessKey', key);
@@ -40,6 +40,7 @@ function createToolButton(icon,label,key,id,classname){
         icon = DOKU_BASE + 'lib/images/toolbar/' + icon;
     }
     $ico.attr('src', icon);
+    $ico.attr('alt', '');
     $ico.attr('width', 16);
     $ico.attr('height', 16);
     $btn.append($ico);
@@ -76,6 +77,7 @@ function createPicker(id,props,edid){
     function $makebutton(title) {
         var $btn = jQuery(document.createElement('button'))
             .addClass('pickerbutton').attr('title', title)
+            .attr('aria-controls', edid)
             .bind('click', bind(pickerInsert, title, edid))
             .appendTo($picker);
         return $btn;
@@ -93,6 +95,7 @@ function createPicker(id,props,edid){
             }
             jQuery(document.createElement('img'))
                 .attr('src', item)
+                .attr('alt', '')
                 .appendTo($makebutton(key));
         }else if (typeof item == 'string'){
             // a list of text -> treat as text picker
@@ -131,10 +134,13 @@ function pickerInsert(text,edid){
  */
 function addBtnActionSignature($btn, props, edid) {
     if(typeof SIG != 'undefined' && SIG != ''){
-        $btn.bind('click', bind(insertAtCarret,edid,SIG));
-        return true;
+        $btn.bind('click', function (e) {
+            insertAtCarret(edid,SIG);
+            e.preventDefault();
+        });
+        return edid;
     }
-    return false;
+    return '';
 }
 
 /**
@@ -145,7 +151,7 @@ function addBtnActionSignature($btn, props, edid) {
 function currentHeadlineLevel(textboxId){
     var field = jQuery('#' + textboxId)[0],
         s = false,
-        opts = [field.value.substr(0,getSelection(field).start)];
+        opts = [field.value.substr(0,DWgetSelection(field).start)];
     if (field.form.prefix) {
         // we need to look in prefix context
         opts.push(field.form.prefix.value);
@@ -214,10 +220,10 @@ jQuery(function () {
         }
 
         // set focus and place cursor at the start
-        var sel = getSelection($edit_text[0]);
+        var sel = DWgetSelection($edit_text[0]);
         sel.start = 0;
         sel.end   = 0;
-        setSelection(sel);
+        DWsetSelection(sel);
         $edit_text.focus();
     }
 
